gpiolookup = {[0]=3,[1]=10,[2]=4,[3]=9,[4]=1,[5]=2,[10]=12,[12]=6,[13]=7,[14]=5,[15]=8,[16]=0}
serverip = "192.168.X.Y"

-- setup I2c and connect display
function init_i2c_display()
     -- SDA and SCL can be assigned freely to available GPIOs
     local sda = gpiolookup[0] -- GPIO0
     local scl = gpiolookup[2] -- GPIO2
     local sla = 0x3c          -- D/C pulled to GND (if high -> 0x3d)
     i2c.setup(0, sda, scl, i2c.SLOW)
--     disp = u8g.ssd1306_128x64_i2c(sla)
	 disp =  u8g.sh1106_128x64_i2c(sla)
end

function getImg( command )
	print( "getImg( \""..command.."\" )" )
	if conn_busy == false or conn_busy == nil then
		conn_busy = true
		local conn = net.createConnection(net.TCP, 0)

		conn:on( "receive", function(conn, payload)
			if( #payload == 1024 ) then
				disp:firstPage()
				repeat
					disp:drawXBM( 0, 0, 128, 64, payload )
				until disp:nextPage() == false
			else
				print( "Nothing to update." )
			end
		end)

		conn:on( "disconnection", function(conn)
--			print("disconnected")
			conn_busy = false
		end)

		conn:on("connection", function(conn)
			conn:send( command.."\n" )
		end)

		conn:connect( 1056, serverip )
	else
		print( "conn_busy" )
		--conn:close()
		conn_busy = false
	end
end

function bell()
	-- Do bell animation...
	tmr.stop( 0 )

	file.open("bell_ring.mono", "r")
	ring_data = file.read()
	file.close()
	file.open("bell.mono", "r")
	bell_data = file.read()
	file.close()

	for i=1,8 do
		disp:firstPage()
		repeat
			disp:drawXBM( 32, 0, 64, 64, ring_data )
		until disp:nextPage() == false
		tmr.delay( 500 * 1000 )
		disp:firstPage()
		repeat
			disp:drawXBM( 32, 0, 64, 64, bell_data )
		until disp:nextPage() == false
		tmr.delay( 500 * 1000 )
	end

	-- has to be done through timer, as apparently you cannot make a tcp-connection from within
	-- udp callback-function...
	tmr.start( 1 )

	-- Enable update-timer
	tmr.start( 0 )
end


-- Set up display...
init_i2c_display()

-- register update-timer
-- update-command tells server to look into cache
tmr.register( 0, ( 30 * 1000 ), tmr.ALARM_AUTO, function() getImg( "updt" ) end )
tmr.register( 1, 1000, tmr.ALARM_AUTO, function()
	getImg( "pull" )
	tmr.stop( 1 )
end )

-- UDP listener erstellen
srv = net.createServer( net.UDP )

srv:on( "receive", function( srv, command )
	if( command == "bell" ) then
		print( "bell" )
		bell()
	end
end)

-- listen on port 18
srv:listen( 18 )

-- get first image
-- pull-command asks server to not look into cache...
getImg( "pull" )

-- start update-timer
tmr.start( 0 )

